<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>AllFields</name>
    <message>
        <location filename="../details.cpp" line="698"/>
        <source>Field</source>
        <translation>Felt</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="698"/>
        <source>Field name</source>
        <translation>Feltnavn</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="699"/>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="699"/>
        <source>Field description</source>
        <translation>Feltbeskrivelse</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="700"/>
        <source>Value</source>
        <translation>Verdi</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="700"/>
        <source>Field value</source>
        <translation>Feltverdi</translation>
    </message>
</context>
<context>
    <name>Boxvar</name>
    <message>
        <location filename="../prefs.cpp" line="61"/>
        <source>Exit On Close Button</source>
        <translation>Avslutt ved lukkeknapp</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="79"/>
        <source>Host Name Lookup</source>
        <translation>Oppslåelse av vertsnavn</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="80"/>
        <source>Service Name Lookup</source>
        <translation>Oppslåelse av servicenavn</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="86"/>
        <source>Disclosure Triangles</source>
        <translation>Avsløringstrekanter</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="87"/>
        <source>Branch Lines</source>
        <translation>Grenlinjer</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="93"/>
        <source>Auto Save Settings on Exit</source>
        <translation>Autolagre innstillinger ved avslutning</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="94"/>
        <source>Selection: Copy PIDs to Clipboard</source>
        <translation>Markering: Kopier PIDer til utklippsboken</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="96"/>
        <source>Normalize NICE</source>
        <translation>Normaliser prioritering</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="97"/>
        <source>Use pmap for Map Names</source>
        <translation>Bruk pmap til kartnavn</translation>
    </message>
</context>
<context>
    <name>Cbgroup</name>
    <message>
        <location filename="../prefs.cpp" line="117"/>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
</context>
<context>
    <name>Command</name>
    <message>
        <location filename="../command.cpp" line="209"/>
        <source>The command:

</source>
        <translation>Kommandoen:

</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="213"/>
        <source>

failed with the error:

</source>
        <translation>

mislyktes med feilen:

</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="216"/>
        <source>Too many processes</source>
        <translation>For mange prosesser</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="219"/>
        <source>Unknown error</source>
        <translation>Ukjent feil</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="229"/>
        <source>

could not be executed because it was not found,
or you did not have execute permission.</source>
        <translation>

kunne ikke utføres fordi den ikke ble funnet
eller du ikke hadde tillatelse til å kjøre den.</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="234"/>
        <source>

exited with status </source>
        <translation>

avsluttet med status </translation>
    </message>
    <message>
        <location filename="../command.cpp" line="238"/>
        <source>Command Failed</source>
        <translation>Kommandoen mislyktes</translation>
    </message>
</context>
<context>
    <name>CommandDialog</name>
    <message>
        <location filename="../commanddialog.cpp" line="47"/>
        <source>Edit Commands 0.1 alpha</source>
        <translation>Rediger kommandoer 0,1 alfa</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="63"/>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="79"/>
        <source>Popup</source>
        <translation>Sprettopp</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="84"/>
        <source>Command Line:</source>
        <translation>Kommandolinje:</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="95"/>
        <source>Substitutions:
%p	PID
%c	COMMAND
%C	CMDLINE
%u	USER
%%	%

</source>
        <translation>Erstatninger:
%p	PID
%c	KOMMANDO
%C	KOMMANDOLINJE
%u	BRUKER
%%	%

</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="109"/>
        <source>New...</source>
        <translation>Ny...</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="111"/>
        <location filename="../commanddialog.cpp" line="229"/>
        <source>Add...</source>
        <translation>Legg til...</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="113"/>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="115"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
</context>
<context>
    <name>ControlBar</name>
    <message>
        <location filename="../misc.cpp" line="925"/>
        <source>Linear</source>
        <translation>Lineær</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="928"/>
        <source>Tree</source>
        <translation>Tre</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="949"/>
        <source>All Processes</source>
        <translation>Alle prosesser</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="950"/>
        <source>Your Processes</source>
        <translation>Dine prosesser</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="951"/>
        <source>Non-Root Processes</source>
        <translation>Ikke-rot-prosesser</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="952"/>
        <source>Running Processes</source>
        <translation>Kjørende prosesser</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="984"/>
        <source>Pause (Ctrl+Space)</source>
        <translation>Pause (Ctrl+Mellomrom)</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../details.cpp" line="36"/>
        <source>Process %1 ( %2 ) - details</source>
        <translation>Prosess %1 ( %2 ) - detaljer</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="45"/>
        <source>Files</source>
        <translation>Filer</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="54"/>
        <source>Sockets</source>
        <translation>Sokler</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="59"/>
        <source>Memory Maps</source>
        <translation>Hukommelseskart</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="61"/>
        <source>Environment</source>
        <translation>Miljø</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="62"/>
        <source>All Fields</source>
        <translation>Alle felt</translation>
    </message>
</context>
<context>
    <name>Environ</name>
    <message>
        <location filename="../details.cpp" line="609"/>
        <source>Variable</source>
        <translation>Variabel</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="609"/>
        <source>Variable name</source>
        <translation>Variabelnavn</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="610"/>
        <source>Value</source>
        <translation>Verdi</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="610"/>
        <source>Variable value</source>
        <translation>Variabelnavn</translation>
    </message>
</context>
<context>
    <name>EventDialog</name>
    <message>
        <location filename="../watchdog.ui" line="23"/>
        <source>Watchdog 0.1 alpha</source>
        <translation>Vaktbikkje 0.1 alfa</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="117"/>
        <source>Eventcat</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="162"/>
        <source>Select condition</source>
        <translation>Velg betingelse</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="170"/>
        <source>labelDescrition</source>
        <translation>etikettbeskrivelse</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="193"/>
        <source>Enable</source>
        <translation>Skru på</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="219"/>
        <source>process name</source>
        <translation>prosessnavn</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="229"/>
        <source>cpu</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="248"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="280"/>
        <source>include already running process</source>
        <translation>inkluder allerede kjørende prosess</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="309"/>
        <source>run command</source>
        <translation>kjør kommando</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="342"/>
        <source>show Message</source>
        <translation>vis beskjed</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="367"/>
        <source>Help (Not yet. just concept)</source>
        <translation>Hjelp (foreløpig bare et konsept)</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="394"/>
        <source>%p : pid
%c : command</source>
        <translation>%p : pid
%c : kommando</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="425"/>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="432"/>
        <source>Add</source>
        <translation>Legg til</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="439"/>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="446"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
</context>
<context>
    <name>ExecWindow</name>
    <message>
        <location filename="../message.ui" line="13"/>
        <source>Qps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../message.ui" line="27"/>
        <source>Ok</source>
        <translation>Okei</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="42"/>
        <source>Qps Watchdog</source>
        <translation>Qps-vaktbikkje</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="97"/>
        <source>%1 exit with code %2</source>
        <translation>%1 avsluttet med koden %2</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="99"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="105"/>
        <source>%1 [running]</source>
        <translation>%1 [kjører]</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="106"/>
        <source>terminate command</source>
        <translation>avslutt kommando</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="115"/>
        <source>Error %1 : [%2] Maybe command not found</source>
        <translation>Feil %1 : [%2] Kanskje finnes kommandoen ikke</translation>
    </message>
</context>
<context>
    <name>FieldSelect</name>
    <message>
        <location filename="../fieldsel.cpp" line="34"/>
        <source>Select Custom Fields </source>
        <translation>Velg tilpassede felter </translation>
    </message>
    <message>
        <location filename="../fieldsel.cpp" line="68"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
</context>
<context>
    <name>Files</name>
    <message>
        <location filename="../details.cpp" line="525"/>
        <source>Fd</source>
        <translation>Fb</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="525"/>
        <source>File descriptor</source>
        <translation>Filbeskrivelse</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="527"/>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="527"/>
        <source>Open mode</source>
        <translation>Åpen modus</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="529"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="529"/>
        <source>File name (if available)</source>
        <translation>Filnavn (hvis tilgjengelig)</translation>
    </message>
</context>
<context>
    <name>IntervalDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="51"/>
        <source>Change Update Period</source>
        <translation>Skift oppdateringsperiode</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="57"/>
        <source>New Update Period</source>
        <translation>Ny oppdateringsperiode</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="94"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="96"/>
        <source>OK</source>
        <translation>Okei</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="130"/>
        <source>No UPDATE</source>
        <translation>Ingen oppdatering</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="148"/>
        <source>Invalid value</source>
        <translation>Ugyldig verdi</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="../listmodel.cpp" line="66"/>
        <source>Event Category</source>
        <translation>Begivenhetskategori</translation>
    </message>
    <message>
        <location filename="../listmodel.cpp" line="68"/>
        <source>Enable</source>
        <translation>Skru på</translation>
    </message>
</context>
<context>
    <name>Maps</name>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Address Range</source>
        <translation>Adresseområde</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Mapped addresses (hex) )</source>
        <translation>Kartlagte addresser (hex) )</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Kbytes mapped (dec)</source>
        <translation>kByte kartlagt (dec)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>Perm</source>
        <translation>Till</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>Permission flags</source>
        <translation>Tillatelsesflagg</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="399"/>
        <source>Offset</source>
        <translation>Forskyving</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="399"/>
        <source>File offset at start of mapping (hex)</source>
        <translation>Filforskyving ved begynnelse av kartlegging (hex)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="400"/>
        <source>Device</source>
        <translation>Enhet</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="400"/>
        <source>Major,Minor device numbers (dec)</source>
        <translation>Store, små enhetsnummer (dec)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="401"/>
        <source>Inode</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="401"/>
        <source>Inode number (dec)</source>
        <translation>Inode-nummer (dec)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="402"/>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="402"/>
        <source>File name (if available)</source>
        <translation>Filnavn (hvis tilgjengelig)</translation>
    </message>
</context>
<context>
    <name>PermissionDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="273"/>
        <source>Permission</source>
        <translation>Tillatelse</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="282"/>
        <source>Root password</source>
        <translation>Rot-passord</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="289"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>OK</source>
        <translation>Okei</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../prefs.cpp" line="166"/>
        <source>Preferences</source>
        <translation>Valg</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="173"/>
        <source>Setting</source>
        <translation>Innstilling</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="235"/>
        <source>%CPU divided by</source>
        <translation>%CPU delt på</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="242"/>
        <source>Total cpu: %1</source>
        <translation>Samlet cpu: %1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="243"/>
        <source>Single cpu: 1</source>
        <translation>Enkel cpu: 1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="249"/>
        <source>default</source>
        <translation>standard</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="250"/>
        <source>for developer</source>
        <translation>for utvikler</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="286"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
</context>
<context>
    <name>Proc</name>
    <message>
        <location filename="../proc.cpp" line="1894"/>
        <source>PID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1894"/>
        <source>Process ID</source>
        <translation>Prosess-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1896"/>
        <source>TGID</source>
        <translation>OGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1896"/>
        <source>Task group ID ( parent of threads )</source>
        <translation>Oppgavens gruppe ID ( foreldre til tråder )</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1898"/>
        <source>PPID</source>
        <translation>FPID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1898"/>
        <source>Parent process ID</source>
        <translation>Forelderens prosess-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1900"/>
        <source>PGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1900"/>
        <source>Process group ID</source>
        <translation>Prosessens gruppe-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1902"/>
        <source>SID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1902"/>
        <source>Session ID</source>
        <translation>Sesjon-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1904"/>
        <source>TTY</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1904"/>
        <source>Terminal</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1906"/>
        <source>TPGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1906"/>
        <source>Process group ID of tty owner</source>
        <translation>Prosessens gruppe-ID av tty-eier</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1908"/>
        <source>USER</source>
        <translation>BRUKER</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1908"/>
        <source>Owner (*=suid root, +=suid a user)</source>
        <translation>Eier (*=suid rot, +=suid en bruker)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1910"/>
        <source>GROUP</source>
        <translation>GRUPPE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1910"/>
        <source>Group name (*=sgid other)</source>
        <translation>Gruppenavn (*=sgid annet)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1912"/>
        <source>UID</source>
        <translation>BID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1912"/>
        <source>Real user ID</source>
        <translation>Virkelig bruker-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1914"/>
        <source>EUID</source>
        <translation>EBID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1914"/>
        <source>Effective user ID</source>
        <translation>Effektiv bruker-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1916"/>
        <source>SUID</source>
        <translation>LBID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1916"/>
        <source>Saved user ID (Posix)</source>
        <translation>Lagret bruker-ID (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1918"/>
        <source>FSUID</source>
        <translation>FSBID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1918"/>
        <source>File system user ID</source>
        <translation>Filsystemets bruker-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1920"/>
        <source>GID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1920"/>
        <source>Real group ID</source>
        <translation>Virkelig gruppe-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1922"/>
        <source>EGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1922"/>
        <source>Effective group ID</source>
        <translation>Effektiv gruppe-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1924"/>
        <source>SGID</source>
        <translation>LGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1924"/>
        <source>Saved group ID (Posix)</source>
        <translation>Lagret gruppe-ID (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1926"/>
        <source>FSGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1926"/>
        <source>File system group ID</source>
        <translation>Filsystemets gruppe-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1928"/>
        <source>PRI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1928"/>
        <source>Dynamic priority</source>
        <translation>Dynamisk prioritet</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1930"/>
        <source>NICE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1930"/>
        <source>Scheduling favour (higher -&gt; less cpu time)</source>
        <translation>Planleggingsfavør (større -&gt; mindre cpu-tid)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1932"/>
        <source>NLWP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1932"/>
        <source>Number of tasks(threads) in task group</source>
        <translation>Antallet oppgaver (tråder) i oppgavegruppe</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1934"/>
        <source>PLCY</source>
        <translation>PLTK</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1934"/>
        <source>Scheduling policy</source>
        <translation>Planleggingspolitikk</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1936"/>
        <source>RPRI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1936"/>
        <source>Realtime priority (0-99, more is better)</source>
        <translation>Realtidsprioritet (0-99, mer er bedre)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1938"/>
        <source>TMS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1938"/>
        <source>Time slice in milliseconds</source>
        <translation>Tidsskive i millisekunder</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1940"/>
        <source>%SAVG</source>
        <translation>%GST</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1940"/>
        <source>Percentage average sleep time (-1 -&gt; N/A)</source>
        <translation>Prosent gjennomsnittlig søvntid (-1 -&gt; ikke relevant)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1942"/>
        <source>CPUSET</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1942"/>
        <source>Affinity CPU mask (0 -&gt; API not supported)</source>
        <translation>Affinitet CPU-maske (0 -&gt; API støttes ikke)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1944"/>
        <source>MAJFLT</source>
        <translation>STØFIL</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1944"/>
        <source>Number of major faults (disk access)</source>
        <translation>Antall større feil (disktilgang)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1946"/>
        <source>MINFLT</source>
        <translation>MINFIL</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1946"/>
        <source>Number of minor faults (no disk access)</source>
        <translation>Antall mindre feil (disktilgang)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1949"/>
        <source>VSIZE</source>
        <translation>VSTØR</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1949"/>
        <source>Virtual image size of process</source>
        <translation>Virtuelt avtrykksstørrelse for prosess</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1951"/>
        <source>RSS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1951"/>
        <source>Resident set size</source>
        <translation>Resident set-størrelse</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1953"/>
        <source>MEM</source>
        <translation>HUK</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1953"/>
        <source>memory usage (RSS-SHARE)</source>
        <translation>hukommelsesbruk (RSS-DELING)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1955"/>
        <source>TRS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1955"/>
        <source>Text(code) resident set size</source>
        <translation>Tekst (kode) resident set-størrelse</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1957"/>
        <source>DRS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1957"/>
        <source>Data resident set size(malloc+global variable)</source>
        <translation>Data resident set-størrelse (malloc+global variabel)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1959"/>
        <source>STACK</source>
        <translation>STAK</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1959"/>
        <source>Stack size</source>
        <translation>Stakstørrelse</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1961"/>
        <source>SHARE</source>
        <translation>DELT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1961"/>
        <source>Shared memory with other libs</source>
        <translation>Delt hukommelse med andre bibliotek</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1963"/>
        <source>SWAP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1963"/>
        <source>Kbytes on swap device</source>
        <translation>kByte på swap-enhet</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1965"/>
        <source>IO_R</source>
        <translation>IO_L</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1965"/>
        <source>io read (file)</source>
        <translation>io-les (fil)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1967"/>
        <source>IO_W</source>
        <translation>IO_S</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1967"/>
        <source>io write (file)</source>
        <translation>io-skriv (fil)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1969"/>
        <source>DT</source>
        <translation>SS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1969"/>
        <source>Number of dirty (non-written) pages</source>
        <translation>Antall skitne (ikke skrevne) sider</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1971"/>
        <source>STAT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1971"/>
        <source>State of the process </source>
        <translation>Prosessens tilstand </translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1973"/>
        <source>FLAGS</source>
        <translation>FLAG</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1973"/>
        <source>Process flags (hex)</source>
        <translation>Prosessflagg (hex)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1975"/>
        <source>WCHAN</source>
        <translation>WKAN</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1975"/>
        <source>Kernel function where process is sleeping</source>
        <translation>Kjernefunksjon hvor prosessen sover</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1977"/>
        <source>%WCPU</source>
        <translation>%VCPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1977"/>
        <source>Weighted percentage of CPU (30 s average)</source>
        <translation>Vektet prosent av CPU (30 s gjennomsnitt)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1979"/>
        <source>%CPU</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1979"/>
        <source>Percentage of CPU used since last update</source>
        <translation>Prosent av CPU brukt siden siste oppdatering</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1981"/>
        <source>%MEM</source>
        <translation>%HUK</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1981"/>
        <source>Percentage of memory used (RSS/total mem)</source>
        <translation>Prosent av hukommelsen brukt (RSS/total hukommelse)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1983"/>
        <source>START</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1983"/>
        <source>Time process started</source>
        <translation>Tidspunkt prosessen startet</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1985"/>
        <source>TIME</source>
        <translation>TID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1985"/>
        <source>Total CPU time used since start</source>
        <translation>Total CPU-tid brukt siden starten</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1987"/>
        <source>CPU</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1987"/>
        <source>CPU the process is executing on (SMP system)</source>
        <translation>CPU prosessen kjører på (SMP-system)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1989"/>
        <source>the process name</source>
        <translation>prosessens navn</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1989"/>
        <source>Process Name</source>
        <translation>Prosessnavn</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1993"/>
        <source>CWD</source>
        <translation>NAM</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1993"/>
        <source>Current working directory</source>
        <translation>Nåværende arbeidsmappe</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1994"/>
        <source>ROOT</source>
        <translation>ROT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1994"/>
        <source>Root directory of process</source>
        <translation>Rotmappen for prosessen</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1997"/>
        <source>COMMAND_LINE</source>
        <translation>KOMMANDOLINJE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1997"/>
        <source>Command line that started the process</source>
        <translation>Kommandolinje som startet prosessen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../qps.cpp" line="2215"/>
        <source>Show</source>
        <translation>Vis</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="2218"/>
        <source>Hide</source>
        <translation>Skjul</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="2224"/>
        <source>ScreenShot</source>
        <translation>Skjermbilde</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="2229"/>
        <source>Quit</source>
        <translation>Avslutt</translation>
    </message>
</context>
<context>
    <name>Qps</name>
    <message>
        <location filename="../qps.cpp" line="189"/>
        <source>header_popup</source>
        <translation>header_sprettopp</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="190"/>
        <source>Remove Field</source>
        <translation>Fjern felt</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="191"/>
        <source>Add Field</source>
        <translation>Legg til felt</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="197"/>
        <source>Command</source>
        <translation>Kommando</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="201"/>
        <source>View</source>
        <translation>Visning</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="202"/>
        <source>Process</source>
        <translation>Prosess</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="203"/>
        <source>Log</source>
        <translation>Logg</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="207"/>
        <source>Custom Fields</source>
        <translation>Tilpassede felt</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="209"/>
        <source>Basic Fields </source>
        <translation>Grunnleggende felt </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="211"/>
        <source>Jobs Fields </source>
        <translation>Jobbfelt </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="213"/>
        <source>Memory Fields </source>
        <translation>Hukommelsesfelt </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="216"/>
        <source>Scheduling Fields </source>
        <translation>Planleggingsfelt </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="222"/>
        <source>Select Custom Fields...</source>
        <translation>Velg tilpassede felt...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="236"/>
        <source>Option</source>
        <translation>Valg</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="237"/>
        <source>Update Period...</source>
        <translation>Oppdateringsintervall...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="246"/>
        <source>Show Status bar</source>
        <translation>Vis statuslinje</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="255"/>
        <source>Preferences...</source>
        <translation>Innstillinger...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="261"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="263"/>
        <location filename="../qps.cpp" line="2291"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="354"/>
        <source>Detail</source>
        <translation>Detalj</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="395"/>
        <source>test</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="396"/>
        <source>Copied to Clipboard</source>
        <translation>Kopiert til utklippsboken</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="505"/>
        <source>context popup</source>
        <translation>sprettoppmeny</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="506"/>
        <source>Renice...</source>
        <translation>Forandre prioritet...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="507"/>
        <source>Scheduling...</source>
        <translation>Planlegging...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="509"/>
        <source>Terminate</source>
        <translation>Avslutt</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="511"/>
        <source>Hangup</source>
        <translation>Legg på</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="512"/>
        <source>Kill</source>
        <translation>Drep</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="513"/>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="515"/>
        <source>Continue</source>
        <translation>Fortsett</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="528"/>
        <source>SIGINT (interrupt)</source>
        <translation>SIGINT (avbryt)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="530"/>
        <source>SIGCONT (continue)</source>
        <translation>SIGCONT (fortsett)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="532"/>
        <source>SIGSTOP (stop)</source>
        <translation>SIGSTOP (stopp)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="534"/>
        <source>SIGQUIT (quit)</source>
        <translation>SIGQUIT (avslutt)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="536"/>
        <source>SIGILL (illegal instruction)</source>
        <translation>SIGILL (ulovlig instruksjon)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="538"/>
        <source>SIGABRT (abort)</source>
        <translation>SIGABRT (avbryt)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="540"/>
        <source>SIGFPE (floating point exception)</source>
        <translation>SIGFPE (Feil med flytende desimaltall)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="542"/>
        <source>SIGSEGV (segmentation violation)</source>
        <translation>SIGSEGV (feil med oppdeling)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="544"/>
        <source>SIGPIPE (broken pipe)</source>
        <translation>SIGPIPE (ødelagt rør [|])</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="546"/>
        <source>SIGALRM (timer signal)</source>
        <translation>SIGALRM (timersignal)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="548"/>
        <source>SIGUSR1 (user-defined 1)</source>
        <translation>SIGUSR1 (brukerdefinert 1)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="550"/>
        <source>SIGUSR2 (user-defined 2)</source>
        <translation>SIGUSR2 (brukerdefinert 2)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="552"/>
        <source>SIGCHLD (child death)</source>
        <translation>SIGCHLD (barnedød)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="554"/>
        <source>SIGTSTP (stop from tty)</source>
        <translation>SIGTSTP (stopp fra tty)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="556"/>
        <source>SIGTTIN (tty input)</source>
        <translation>SIGTTIN (tty-innsignal)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="558"/>
        <source>SIGTTOU (tty output)</source>
        <translation>SIGTTOU (tty-utsignal)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="565"/>
        <source>View Details</source>
        <translation>Vis detaljer</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1181"/>
        <source>WatchDog</source>
        <translation>Vaktbikkje</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1185"/>
        <source>Edit Commands...</source>
        <translation>Rediger kommandoer...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1210"/>
        <source>Quit</source>
        <translation>Avslutt</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1590"/>
        <location filename="../qps.cpp" line="1627"/>
        <location filename="../qps.cpp" line="1634"/>
        <location filename="../qps.cpp" line="1656"/>
        <location filename="../qps.cpp" line="1694"/>
        <location filename="../qps.cpp" line="1773"/>
        <source>Permission denied</source>
        <translation>Nektet tillatelse</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1591"/>
        <source>You do not have permission to renice the selected processes. Only the process owner and the super-user are allowed to do that.</source>
        <translation>Du har ikke tillatelse til å forandre prioritet for den valgte prosessen. Bare prosessens eier og superbrukeren har tillatelse til det.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1628"/>
        <source>You do not have permission to renice process %1 (%2).Only the process owner and the super-user are allowed to do that.</source>
        <translation>Du har ikke tillatelse til å forandre prioritet på prosessen %1 (%2). Bare prosessens eier og superbrukeren har tillatelse til det.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1635"/>
        <source>Only the super-user may lower the nice value of a process.</source>
        <translation>Bare superbrukeren kan minske nice-verdien til en prosess.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1657"/>
        <source>Only the super-user may change the scheduling policy and static priority.</source>
        <translation>Bare superbrukeren kan forandre planlegginspolitikken og statisk prioritering.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1695"/>
        <source>You do not have permission to change the scheduling and/or priority of process %1 (%2). Only the super-user may do that.</source>
        <translation>Du har ikke tillatelse til å forandre planleggingen og/eller proriteten til prosessen %1 (%2). Bare superbrukeren kan gjøre det.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1774"/>
        <source>You do not have permission to send a signal to process %1 (%2). Only the super-user and the owner of the process may send signals to it.</source>
        <translation>Du har ikke tillatelse til å sende et signal til prosessen %1 (%2). Bare superbrukeren og eieren av prosessen kan gjøre det.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="2311"/>
        <source>&lt;h2&gt; Qps %1 - A Visual Process Manager &lt;/h2&gt; %2 using Qt library %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Source: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;</source>
        <translation>&lt;h2&gt; Qps %1 - En visuell prosesshåndterer&lt;/h2&gt; %2 som bruker Qt-biblioteket %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Kilde: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Feilhåndterer: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="2331"/>
        <source>&lt;b&gt;Original Qps by&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Contributors&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</source>
        <translation>&lt;b&gt;Orginal Qps av&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Bidragsytere&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="2373"/>
        <source>&lt;H1&gt;QPS Help&lt;/H1&gt;Updated: May 24 2005&lt;BR&gt;&lt;A HREF=&quot;http://kldp.net/projects/qps&quot;&gt;http://kldp.net/projects/qps&lt;/A&gt;&lt;HR&gt;&lt;table style=&quot;text-align: center; width: 100%;&quot; border=&quot;1&quot; cellpadding=&quot;1&quot; cellspacing=&quot;0&quot;&gt;  &lt;tbody&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;Quit      &lt;/td&gt;      &lt;td &gt;&amp;nbsp; CTRL + q , CTRL + x      &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;Update      &lt;/td&gt;      &lt;td&gt;&amp;nbsp;Space , Enter       &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; process Terminate &lt;/td&gt;  &lt;td&gt; ALT + T , DELETE &lt;/td&gt; &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; process Kill &lt;/td&gt;  &lt;td&gt; ALT + K  &lt;/td&gt; &lt;/tr&gt;  &lt;/tbody&gt;&lt;/table&gt;</source>
        <translation>&lt;H1&gt;QPS Hjelp&lt;/H1&gt;Oppdatert 24. mai 2005&lt;BR&gt;&lt;A HREF=&quot;http://kldp.net/projects/qps&quot;&gt;http://kldp.net/projects/qps&lt;/A&gt;&lt;HR&gt;&lt;table style=&quot;text-align: center; width: 100%;&quot; border=&quot;1&quot; cellpadding=&quot;1&quot; cellspacing=&quot;0&quot;&gt;  &lt;tbody&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;Avslutt      &lt;/td&gt;      &lt;td &gt;&amp;nbsp; CTRL + q , CTRL + x      &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;Oppdater      &lt;/td&gt;      &lt;td&gt;&amp;nbsp;Mellomrom , Retur       &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; Avslutt prosess &lt;/td&gt;  &lt;td&gt; ALT + T , DELETE &lt;/td&gt; &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; Drep prosess &lt;/td&gt;  &lt;td&gt; ALT + K  &lt;/td&gt; &lt;/tr&gt;  &lt;/tbody&gt;&lt;/table&gt;</translation>
    </message>
</context>
<context>
    <name>SchedDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="301"/>
        <source>Change scheduling</source>
        <translation>Skift planlegging</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="305"/>
        <source>Scheduling Policy</source>
        <translation>Planleggingspolitikk</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="307"/>
        <source>SCHED_OTHER (time-sharing)</source>
        <translation>PLANL_ANNET (tidsdeling)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="308"/>
        <source>SCHED_FIFO (real-time)</source>
        <translation>PLANL_FIFO (realtid)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="309"/>
        <source>SCHED_RR (real-time)</source>
        <translation>PLANL_RR (realtid)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="323"/>
        <source>OK</source>
        <translation>Okei</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="325"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="355"/>
        <source>Priority (1-99):</source>
        <translation>Prioritet (1-99):</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="388"/>
        <source>Invalid Input</source>
        <translation>Ugyldig innverdi</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="389"/>
        <source>The priority must be in the range 1..99</source>
        <translation>Prioriteten må være mellom 1 og 99</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <location filename="../screenshot.cpp" line="294"/>
        <source>/untitled.</source>
        <translation>/uten navn.</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="299"/>
        <source>Save As</source>
        <translation>Lagre som</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="300"/>
        <source>%1 Files (*.%2);;All Files (*)</source>
        <translation>%1 filer (*.%2);;Alle filer (*)</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="327"/>
        <source>Options</source>
        <translation>Valg</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="330"/>
        <source> s</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="335"/>
        <source>Screenshot Delay:</source>
        <translation>Forsinkelse for skjermbilde:</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="337"/>
        <source>Hide This Window</source>
        <translation>Skjul dette vinduet</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="349"/>
        <source>New Screenshot</source>
        <translation>Nytt skjermbilde</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="350"/>
        <source>Quit</source>
        <translation>Avslutt</translation>
    </message>
</context>
<context>
    <name>SearchBox</name>
    <message>
        <location filename="../misc.cpp" line="806"/>
        <source>PID,COMMAND,USER...</source>
        <translation>PID,KOMMANDO,BRUKER...</translation>
    </message>
</context>
<context>
    <name>SliderDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="188"/>
        <source>Renice Process</source>
        <translation>Forandre prioritet for prosess</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="194"/>
        <source>New nice value:</source>
        <translation>Ny prioriteringsverdi:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="234"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="238"/>
        <source>OK</source>
        <translation>Okei</translation>
    </message>
</context>
<context>
    <name>Sockets</name>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Fd</source>
        <translation>Fb</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>File descriptor</source>
        <translation>Filbeskrivelse</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <source>Proto</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <source>Protocol (TCP or UDP)</source>
        <translation>Protokoll (TCP eller UDP)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Recv-Q</source>
        <translation>Motkø</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Bytes in receive queue</source>
        <translation>Byte i mottakskø</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="154"/>
        <source>Send-Q</source>
        <translation>Sendkø</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="154"/>
        <source>Bytes in send queue</source>
        <translation>Byte i sendekø</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>Local Addr</source>
        <translation>Lokal adr</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>Local IP address</source>
        <translation>Lokal IP-adresse</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="156"/>
        <location filename="../details.cpp" line="158"/>
        <source>Port</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="156"/>
        <source>Local port</source>
        <translation>Lokal port</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="157"/>
        <source>Remote Addr</source>
        <translation>Fjernadr</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="157"/>
        <source>Remote IP address</source>
        <translation>Fjern IP-adresse</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="158"/>
        <source>Remote port</source>
        <translation>Fjernport</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="159"/>
        <source>State</source>
        <translation>Tilstand</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="159"/>
        <source>Connection state</source>
        <translation>Status for forbindelse</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../misc.cpp" line="895"/>
        <source>Process count: %1</source>
        <translation>Antall prosesser: %1</translation>
    </message>
</context>
<context>
    <name>TBloon</name>
    <message>
        <location filename="../misc.cpp" line="347"/>
        <source> This is unstable Alpha feature
 You maybe see a SEGFAULT...</source>
        <translation> Dette er en ustabil Alfa funksjon
 Du kan oppleve en SEGFAULT...</translation>
    </message>
</context>
<context>
    <name>TFrame</name>
    <message>
        <location filename="../misc.cpp" line="426"/>
        <source>this is Tframe widget</source>
        <translation>dette er Tframe-widgeten</translation>
    </message>
</context>
<context>
    <name>UFrame</name>
    <message>
        <location filename="../misc.cpp" line="615"/>
        <source>title</source>
        <translation>tittel</translation>
    </message>
</context>
<context>
    <name>WatchdogDialog</name>
    <message>
        <location filename="../watchdogdialog.cpp" line="193"/>
        <source>if process start</source>
        <translation>hvis prosessen starter</translation>
    </message>
    <message>
        <location filename="../watchdogdialog.cpp" line="194"/>
        <source>if process finish</source>
        <translation>hvis prosessen blir ferdig</translation>
    </message>
    <message>
        <location filename="../watchdogdialog.cpp" line="217"/>
        <source>select condition</source>
        <translation>velg betingelse</translation>
    </message>
</context>
</TS>
